import json

import click

from delta.cli.schedule.utils import display_schedule_detailed, format_schedule

from delta.cli.utils import Utils, API

DEFAULT_LIMIT = 15


@click.help_option("--help", "-h")
@click.command(
    name='pause',
    short_help='pause a scheduled DeltaTwin component execution')
@click.option(
    '--conf',
    '-c',
    type=str,
    default=None,
    help='Path to the conf file')
@click.option(
    '--format-output',
    '-f',
    type=str,
    default=None,
    help='Format of the output (json/text). Default is text')
@click.argument('schedule_name')
def pause_deltatwin_schedule(conf, schedule_name, format_output: str):
    """
    Pause the scheduled DeltaTwin component execution.
    """
    schedules = API.pause_scheduled_run(conf, schedule_name)
    schedules = format_schedule(schedules)

    if Utils.output_as_json(format_output, schedules):
        click.echo(json.dumps(schedules, indent=4))
    else:
        display_schedule_detailed(schedules)
